import { PrintData } from "./interface/PrinterDataInterface";
declare type SuperAppLoadedEventListener = () => void;
declare type CashDrawerEventListener = (action: string, requestId: number) => void;
declare type PrinterStatusEventListener = (action: string) => void;
declare type PrintingEventListener = (action: string) => void;
declare type MiniAppCallbackEventListener = (miniAppId: string, data: string) => void;
declare type MiniAppBroadcastEventListener = (data: string) => void;
declare type MiniAppActivityFinishingEventListener = () => boolean;
declare global {
    interface Window {
        SuperApp: any;
    }
}
export default class SuperApp {
    static loadedEventListener: SuperAppLoadedEventListener;
    static setReactSupport(): void;
    static initial(key: string): void;
    static getInfo(): {
        versionCode: number;
        versionName: string;
        buildServer: string;
    };
    static MiniApp: {
        new (): {};
        callbackEventListener: MiniAppCallbackEventListener;
        activityFinishingEventListener: MiniAppActivityFinishingEventListener;
        broadcastEventListener: MiniAppBroadcastEventListener;
        open(miniAppId: string, versionCode: number, data: string): {
            result: boolean;
            message: string;
        };
        getInfo(miniAppId: string): {
            result: boolean;
            message: string;
            version: string;
            name: string;
            displayName: string;
            lastUpdate: string;
        };
        requestShowOnCustomerDisplay(htmlPath: string): void;
        requestHideFromCustomerDisplay(): void;
        broadcastDataToCustomerDisplay(data: string): void;
        getData(): string;
        finish(data: string): void;
    };
    static Terminal: {
        new (): {};
        getInfo(): {
            terminalId: string;
            os: string;
            osVersion: string;
            screenCount: number;
            screenSize: {
                width: number;
                height: number;
            }[];
        };
    };
    static Store: {
        new (): {};
        getInfo(): {
            storeId: string;
            storeName: string;
            language: string;
            companyId: string;
        };
    };
    static User: {
        new (): {};
        getInfo(): {
            userId: string;
            userName: string;
        };
    };
    static Device: {
        new (): {};
        CashDrawer: {
            new (): {};
            listener: CashDrawerEventListener;
            open(requestId: number): Boolean;
            getStatus(): string;
            setCashDrawerEventListener(listener: CashDrawerEventListener): void;
        };
        Printer: {
            new (): {};
            statusListener: PrinterStatusEventListener;
            tempPrintingListener: PrintingEventListener;
            print(printData: PrintData, printingListener: PrintingEventListener): void;
            getStatus(): string;
            setPrinterStatusListener(statusListener: PrinterStatusEventListener): void;
        };
    };
}
export {};
